@@ -12,7 +12,7 @@ Sphinx::Config - Sphinx search engine configuration file read/modify/write
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 SYNOPSIS
 
@@ -156,7 +156,7 @@ sub _parse_file
 			    push(@config, $current);
 			    $seq = "name";
 			}
-			elsif ($tok =~ m/^(?:indexer|searchd|search)$/o) {
+			elsif ($tok =~ m/^(?:indexer|searchd|search|common)$/o) {
                             $current = { _type => $tok, _lines => [ $first ] };
 			    push(@config, $current);
 			    $seq = "openblock";
